@@ -12,8 +12,7 @@ def visualize_measurement_on_labels(labels_layer:"napari.layers.Labels", column:
         measurements = measurements.tolist()
 
     try:
-        import pyclesperanto_prototype as cle
-        return cle.replace_intensities(labels, numpy.asarray([0] + measurements))
+        import pyclesperanto_prototype as cle; return cle.pull(cle.replace_intensities(labels, numpy.asarray([0] + measurements)))
     except ImportError:
         return relabel_numpy(labels, measurements)
 
