@@ -19,10 +19,10 @@ def test_regionprops(make_napari_viewer):
         [0, 0, 0, 0, 0, 0, 0],
         [0, 0, 3, 3, 3, 0, 0],
         [0, 0, 3, 3, 3, 0, 4],
-    ])
+    ]).astype(float)
 
     image_layer = viewer.add_image(image)
-    labels_layer = viewer.add_labels(image)
+    labels_layer = viewer.add_labels(image.astype(int))
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
@@ -131,28 +131,18 @@ def test_regionprops_without_moments(make_napari_viewer):
         [0, 0, 0, 0, 0, 0, 0],
         [0, 0, 3, 3, 3, 4, 4],
         [0, 0, 3, 3, 3, 4, 4],
-    ])
+    ]).astype(float)
 
     # make 3D stack
     image = np.asarray([image, image, image])
 
     image_layer = viewer.add_image(image)
-    labels_layer = viewer.add_labels(image)
+    labels_layer = viewer.add_labels(image.astype(int))
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
     regionprops(image_layer, labels_layer, viewer, True, True, True, True, True, False)
 
-
-def test_regionprops_without_data(make_napari_viewer):
-
-    viewer = make_napari_viewer()
-
-    # analyze everything we can
-    from napari_skimage_regionprops import regionprops
-    regionprops(None, None, viewer)
-
-
 def test_3d_2d(make_napari_viewer):
 
     viewer = make_napari_viewer()
@@ -171,14 +161,14 @@ def test_3d_2d(make_napari_viewer):
         [0, 0, 0, 0, 0, 0, 0],
         [0, 0, 3, 3, 3, 0, 0],
         [0, 0, 3, 3, 3, 0, 4],
-    ])
+    ]).astype(float)
 
     labels = image
     # make a 3D dataset
     image = np.asarray([image, image, image])
 
     image_layer = viewer.add_image(image)
-    labels_layer = viewer.add_labels(labels)
+    labels_layer = viewer.add_labels(labels.astype(int))
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
@@ -214,13 +204,13 @@ def test_3d(make_napari_viewer):
         [0, 0, 0, 0, 0, 0, 0],
         [0, 0, 3, 3, 3, 4, 4],
         [0, 0, 3, 3, 3, 4, 4],
-    ])
+    ]).astype(float)
 
     # make a 3D dataset
     image = np.asarray([image, image, image])
 
     image_layer = viewer.add_image(image)
-    labels_layer = viewer.add_labels(image)
+    labels_layer = viewer.add_labels(image.astype(int))
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
